Index — BCI-Framework documentation

# Index

A | B | D | G | M | P

## A

add_point() (in module bci_framework.default_extensions.Visual_working_memory.points)

## B

bci_framework module bci_framework.default_extensions module bci_framework.default_extensions.Class_motor_imagery module bci_framework.default_extensions.Class_motor_imagery_Pacman module bci_framework.default_extensions.Class_motor_imagery_Pacman.pacman module bci_framework.default_extensions.OpenBCI_Auxiliar_data module bci_framework.default_extensions.OpenBCI_Raw_EEG module bci_framework.default_extensions.OpenBCI_Raw_topoplot module bci_framework.default_extensions.P300_online_classifier module bci_framework.default_extensions.P300_Speller module bci_framework.default_extensions.Resting_state_and_noise_acquisition module | bci_framework.default_extensions.Tutorial_Fourier_stream_consumer module bci_framework.default_extensions.Tutorial_Fourier_stream_produser module bci_framework.default_extensions.Tutorial_Marker_slicing module bci_framework.default_extensions.Tutorial_Objects_measurement module bci_framework.default_extensions.Tutorial_Pipelines module bci_framework.default_extensions.Visual_working_memory module bci_framework.default_extensions.Visual_working_memory.points module bci_framework.kafka_scripts module bci_framework.kafka_scripts.latency_synchronization_stimuli_marker module bci_framework.kafka_scripts.latency_synchronization_visualization module

## D

distance() (in module bci_framework.default_extensions.Visual_working_memory.points)

## G

get_points() (in module bci_framework.default_extensions.Visual_working_memory.points)

## M

module bci_framework bci_framework.default_extensions bci_framework.default_extensions.Class_motor_imagery bci_framework.default_extensions.Class_motor_imagery_Pacman bci_framework.default_extensions.Class_motor_imagery_Pacman.pacman bci_framework.default_extensions.OpenBCI_Auxiliar_data bci_framework.default_extensions.OpenBCI_Raw_EEG bci_framework.default_extensions.OpenBCI_Raw_topoplot bci_framework.default_extensions.P300_online_classifier bci_framework.default_extensions.P300_Speller bci_framework.default_extensions.Resting_state_and_noise_acquisition bci_framework.default_extensions.Tutorial_Fourier_stream_consumer bci_framework.default_extensions.Tutorial_Fourier_stream_produser bci_framework.default_extensions.Tutorial_Marker_slicing bci_framework.default_extensions.Tutorial_Objects_measurement bci_framework.default_extensions.Tutorial_Pipelines bci_framework.default_extensions.Visual_working_memory bci_framework.default_extensions.Visual_working_memory.points bci_framework.kafka_scripts bci_framework.kafka_scripts.latency_synchronization_stimuli_marker bci_framework.kafka_scripts.latency_synchronization_visualization

## P

point() (in module bci_framework.default_extensions.Visual_working_memory.points)